@@ -1,18 +1,19 @@
 /***************************************************************
  *                 Simula+ configuration file                  *
- *                      simula+@ensam.eu                       *
- *	             GNU/linux version 2.6.0	               *
+ *                    simula.plus@cemes.fr                     *
+ *	             GNU/linux version 3.0.0	               *
  *            software under General Public License            *
  ***************************************************************
- * copyright © 2006 COLLARD Christophe
- * copyright © 2006 Centre National de la Recherche Scientifique
+ * copyright © 2006,2012 COLLARD Christophe
+ * copyright © 2006,2012 Centre National de la Recherche Scientifique
  * copyright © 2006 Arts et Métiers ParisTech
  * copyright © 2006 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
  * copyright © 2006 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
+ * copyright © 2012 Centre d'Elaboration de Matériaux et d'Etudes Structurales (CEMES - CNRS)
  ***************************************************************/
 
-#ifndef _parameters_h
-#define _parameters_h
+#ifndef __parameters_h
+#define __parameters_h
 
 using namespace std;
 #define DEBUG // debug mode
