@@ -1,15 +1,16 @@
 /***************************************************************
- *                    simula+@metz.ensam.fr                    *
- *                   GNU/linux version 2.6.0                   *
+ *                    simula.plus@cemes.fr                     *
+ *                   GNU/linux version 3.0.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright © 2003,2004,2005,2006,2009 COLLARD Christophe
+ * copyright © 2003,2004,2005,2006,2009,2012 COLLARD Christophe
  * copyright © 2003,2004,2005 CREUSE Emmanuel
- * copyright © 2003,2004,2005,2006,2009 Centre National de la Recherche Scientifique
+ * copyright © 2003,2004,2005,2006,2009,2012 Centre National de la Recherche Scientifique
  * copyright © 2003,2004,2005,2006,2009 Arts et Métiers ParisTech
  * copyright © 2003,2004,2005,2006 Université de Valenciennes et du Hainaut-Cambrésis
  * copyright © 2003,2004,2005,2006,2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
  * copyright © 2003,2004,2005,2006 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
+ * copyright © 2012 Centre d'Elaboration de Matériaux et d'Etudes Structurales (CEMES - CNRS)
  ***************************************************************/
 
 /*
@@ -32,103 +33,99 @@
 */
 
 #ifndef __cplusplus
-#error Must use C++ for the type interface.
+#error Must use C++ for the type tests-MOL++
 #endif
 
-#if !defined(__IOSTREAM_H)
+#ifndef __iostream
 #include <iostream>
 #endif
 
-#if !defined(__FSTREAM_H)
+#ifndef __fstream
 #include <fstream>
 #endif
 
-#if !defined(__STDIO_H)
+#ifndef __stdio_h
 #include <stdio.h>
 #endif
 
-#if !defined (__STDLIB_H)
+#ifndef __stdlib_h
 #include <stdlib.h>
 #endif
 
-#if !defined(__TIME_H)
+#ifndef __time_h
 #include <time.h>
 #endif
 
-#if !defined(__COLORS_H)
-#include "colors.h"
+#ifndef __colors_hpp
+#include "colors.hpp"
 #endif
 
-#if !defined(__MATHS_TEST_H)
-#include "maths-test.h"
+#ifndef __maths_test_hpp
+#include "maths-test.hpp"
 #endif
 
-#if !defined(__VECTORS_TEST_H)
-#include "vectors-test.h"
+#ifndef __vectors_test_hpp
+#include "vectors-test.hpp"
 #endif
 
-#if !defined (__MATRIX_TEST_H)
-#include "matrix-test.h"
+#ifndef __matrix_test_hpp
+#include "matrix-test.hpp"
 #endif
 
-#if !defined(__SYMMATRIX_TEST_H)
-#include "symmatrix-test.h"
+#ifndef __symmatrix_test_hpp
+#include "symmatrix-test.hpp"
 #endif
 
-#if !defined(__SPMATRIX_TEST_H)
-#include "spmatrix-test.h"
+#ifndef __spmatrix_test_hpp
+#include "spmatrix-test.hpp"
 #endif
 
-//#if !defined(__BMATRIX_H)
-//#include "bandwidthmatrix-linux.h"
-//#endif
-
-#if !defined(__LINEAR_SYSTEMS_TEST_H)
-#include"linear systems-test.h"
+#ifndef __linear_systems_test_hpp
+#include"linear systems-test.hpp"
 #endif
 
-#if !defined(__TENSORS2_TEST_H)
-#include "tensors2-test.h"
+#ifndef __tensors2_test_hpp
+#include "tensors2-test.hpp"
 #endif
 
-#if !defined(__SYMTENSORS2_TEST_H)
-#include "symtensors2-test.h"
+#ifndef __symtensors2_test_hpp
+#include "symtensors2-test.hpp"
 #endif
 
-#if !defined(__TENSORS3_TEST_H)
-#include "tensors3-test.h"
+#ifndef __tensors3_test_hpp
+#include "tensors3-test.hpp"
 #endif
 
-#if !defined(__TENSORS4_TEST_H)
-#include "tensors4-test.h"
+#ifndef __tensors4_test_hpp
+#include "tensors4-test.hpp"
 #endif
 
-#if !defined(__SYMTENSORS4_TEST_H)
-#include "symtensors4-test.h"
+#ifndef __symtensors4_test_hpp
+#include "symtensors4-test.hpp"
 #endif
 
-#if !defined(__CONVERSION_TOOLS_TEST_H)
-#include "conversion tools-test.h"
+#ifndef __conversion_tools_test_hpp
+#include "conversion tools-test.hpp"
 #endif
 
-#if !defined(__ABAQUS_CONVERSION_TOOLS_TEST_H)
-#include "abaqus conversion tools-test.h"
+#ifndef __ABAQUS_conversion_tools_test_hpp
+#include "abaqus conversion tools-test.hpp"
 #endif
 
-#if !defined(__POLYNOMS_TEST_H)
-#include "polynoms-test.h"
+#ifndef __polynoms_test_hpp
+#include "polynoms-test.hpp"
 #endif
 
-#if !defined(__LEGENDRE_TEST_H)
-#include "legendre-test.h"
+#ifndef __legendre_test_hpp
+#include "legendre-test.hpp"
 #endif
 
-#if !defined(__INTEGRATION_TEST_H)
-#include "integration-test.h"
+#ifndef __integration_test_hpp
+#include "integration-test.hpp"
 #endif
 
-#if !defined(__COMBINATORIAL_ANALYSIS_TEST_H)
-#include "combinatorial analysis-test.h"
+#ifndef __combinatorial_analysis_test_hpp
+#include "combinatorial analysis-test.hpp"
 #endif
 
 /*#if !defined(__ODE_TEST_H)
@@ -150,7 +147,7 @@ main()
   start_main = start = clock();
   if (detail)
     //=======================================================================
-    cout<< "---------------------------maths---------------------------- \n";
+    cout << "---------------------------maths--------------------------- \n";
     //=======================================================================
   result *= test_maths(detail);
   end = clock();
@@ -162,7 +159,7 @@ main()
   start = clock();
   if (detail)
     //=======================================================================
-    cout<< "---------------------------vector--------------------------- \n";
+    cout << "--------------------------vector--------------------------- \n";
     //=======================================================================
   result *= test_vector(detail);
   end = clock();
